// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: proto/nodeinstance/create/v1/creation.proto
// Protobuf C++ Version: 7.35.0

#ifndef proto_2fnodeinstance_2fcreate_2fv1_2fcreation_2eproto_2epb_2eh
#define proto_2fnodeinstance_2fcreate_2fv1_2fcreation_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

// clang-format off
#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 7035000
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/unknown_field_set.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_proto_2fnodeinstance_2fcreate_2fv1_2fcreation_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_proto_2fnodeinstance_2fcreate_2fv1_2fcreation_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_proto_2fnodeinstance_2fcreate_2fv1_2fcreation_2eproto;
}  // extern "C"
namespace nodeinstance {
namespace create {
namespace v1 {
class CreateNodeInstance;
struct CreateNodeInstanceGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern CreateNodeInstanceGlobalsTypeInternal CreateNodeInstance_globals_;
extern const ::google::protobuf::internal::ClassDataFull CreateNodeInstance_class_data_;
#else
extern const CreateNodeInstanceGlobalsTypeInternal CreateNodeInstance_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class CreateNodeInstanceResult;
struct CreateNodeInstanceResultGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern CreateNodeInstanceResultGlobalsTypeInternal CreateNodeInstanceResult_globals_;
extern const ::google::protobuf::internal::ClassDataFull CreateNodeInstanceResult_class_data_;
#else
extern const CreateNodeInstanceResultGlobalsTypeInternal CreateNodeInstanceResult_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
}  // namespace v1
}  // namespace create
}  // namespace nodeinstance
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google

namespace nodeinstance {
namespace create {
namespace v1 {

// ===================================================================


// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED CreateNodeInstanceResult final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:nodeinstance.create.v1.CreateNodeInstanceResult) */ {
 public:
  inline CreateNodeInstanceResult() : CreateNodeInstanceResult(nullptr) {}
  ~CreateNodeInstanceResult() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(CreateNodeInstanceResult* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(CreateNodeInstanceResult));
  }
#endif

  template <typename = void>
  explicit constexpr CreateNodeInstanceResult(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline CreateNodeInstanceResult(const CreateNodeInstanceResult& from) : CreateNodeInstanceResult(nullptr, from) {}
  inline CreateNodeInstanceResult(CreateNodeInstanceResult&& from) noexcept : CreateNodeInstanceResult(nullptr, ::std::move(from)) {}
  inline CreateNodeInstanceResult& operator=(const CreateNodeInstanceResult& from) {
    CopyFrom(from);
    return *this;
  }
  inline CreateNodeInstanceResult& operator=(CreateNodeInstanceResult&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const CreateNodeInstanceResult& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<CreateNodeInstanceResult>(&CreateNodeInstanceResult_globals_);
  }
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(CreateNodeInstanceResult& a, CreateNodeInstanceResult& b) { a.Swap(&b); }
  inline void Swap(CreateNodeInstanceResult* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(CreateNodeInstanceResult* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] CreateNodeInstanceResult* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<CreateNodeInstanceResult>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const CreateNodeInstanceResult& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const CreateNodeInstanceResult& from) { CreateNodeInstanceResult::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(CreateNodeInstanceResult* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "nodeinstance.create.v1.CreateNodeInstanceResult"; }

  explicit CreateNodeInstanceResult(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  CreateNodeInstanceResult(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const CreateNodeInstanceResult& from);
  CreateNodeInstanceResult(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, CreateNodeInstanceResult&& from) noexcept
      : CreateNodeInstanceResult(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kNodeIdFieldNumber = 1,
    kMachineGuidFieldNumber = 2,
  };
  // string node_id = 1;
  void clear_node_id() ;
  [[nodiscard]] const ::std::string& node_id() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_node_id(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_node_id();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_node_id();
  void set_allocated_node_id(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_node_id() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_node_id(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_node_id();

  public:
  // string machine_guid = 2;
  void clear_machine_guid() ;
  [[nodiscard]] const ::std::string& machine_guid() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_machine_guid(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_machine_guid();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_machine_guid();
  void set_allocated_machine_guid(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_machine_guid() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_machine_guid(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_machine_guid();

  public:
  // @@protoc_insertion_point(class_scope:nodeinstance.create.v1.CreateNodeInstanceResult)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<1, 2,
                          0, 75,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const CreateNodeInstanceResult& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr node_id_;
    ::google::protobuf::internal::ArenaStringPtr machine_guid_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_proto_2fnodeinstance_2fcreate_2fv1_2fcreation_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED CreateNodeInstance final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:nodeinstance.create.v1.CreateNodeInstance) */ {
 public:
  inline CreateNodeInstance() : CreateNodeInstance(nullptr) {}
  ~CreateNodeInstance() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(CreateNodeInstance* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(CreateNodeInstance));
  }
#endif

  template <typename = void>
  explicit constexpr CreateNodeInstance(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline CreateNodeInstance(const CreateNodeInstance& from) : CreateNodeInstance(nullptr, from) {}
  inline CreateNodeInstance(CreateNodeInstance&& from) noexcept : CreateNodeInstance(nullptr, ::std::move(from)) {}
  inline CreateNodeInstance& operator=(const CreateNodeInstance& from) {
    CopyFrom(from);
    return *this;
  }
  inline CreateNodeInstance& operator=(CreateNodeInstance&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const CreateNodeInstance& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<CreateNodeInstance>(&CreateNodeInstance_globals_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(CreateNodeInstance& a, CreateNodeInstance& b) { a.Swap(&b); }
  inline void Swap(CreateNodeInstance* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(CreateNodeInstance* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] CreateNodeInstance* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<CreateNodeInstance>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const CreateNodeInstance& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const CreateNodeInstance& from) { CreateNodeInstance::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(CreateNodeInstance* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "nodeinstance.create.v1.CreateNodeInstance"; }

  explicit CreateNodeInstance(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  CreateNodeInstance(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const CreateNodeInstance& from);
  CreateNodeInstance(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, CreateNodeInstance&& from) noexcept
      : CreateNodeInstance(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kClaimIdFieldNumber = 1,
    kMachineGuidFieldNumber = 2,
    kHostnameFieldNumber = 3,
    kMqttBrokerAddrFieldNumber = 5,
    kVmqInstanceIdFieldNumber = 4,
    kHopsFieldNumber = 6,
  };
  // string claim_id = 1;
  void clear_claim_id() ;
  [[nodiscard]] const ::std::string& claim_id() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_claim_id(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_claim_id();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_claim_id();
  void set_allocated_claim_id(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_claim_id() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_claim_id(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_claim_id();

  public:
  // string machine_guid = 2;
  void clear_machine_guid() ;
  [[nodiscard]] const ::std::string& machine_guid() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_machine_guid(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_machine_guid();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_machine_guid();
  void set_allocated_machine_guid(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_machine_guid() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_machine_guid(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_machine_guid();

  public:
  // string hostname = 3;
  void clear_hostname() ;
  [[nodiscard]] const ::std::string& hostname() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_hostname(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_hostname();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_hostname();
  void set_allocated_hostname(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_hostname() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_hostname(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_hostname();

  public:
  // string mqtt_broker_addr = 5;
  void clear_mqtt_broker_addr() ;
  [[nodiscard]] const ::std::string& mqtt_broker_addr() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_mqtt_broker_addr(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_mqtt_broker_addr();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_mqtt_broker_addr();
  void set_allocated_mqtt_broker_addr(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_mqtt_broker_addr() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_mqtt_broker_addr(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_mqtt_broker_addr();

  public:
  // int32 vmq_instance_id = 4;
  void clear_vmq_instance_id() ;
  [[nodiscard]] ::int32_t vmq_instance_id() const;
  void set_vmq_instance_id(::int32_t value);

  private:
  ::int32_t _internal_vmq_instance_id() const;
  void _internal_set_vmq_instance_id(::int32_t value);

  public:
  // int32 hops = 6;
  void clear_hops() ;
  [[nodiscard]] ::int32_t hops() const;
  void set_hops(::int32_t value);

  private:
  ::int32_t _internal_hops() const;
  void _internal_set_hops(::int32_t value);

  public:
  // @@protoc_insertion_point(class_scope:nodeinstance.create.v1.CreateNodeInstance)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<3, 6,
                          0, 94,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const CreateNodeInstance& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr claim_id_;
    ::google::protobuf::internal::ArenaStringPtr machine_guid_;
    ::google::protobuf::internal::ArenaStringPtr hostname_;
    ::google::protobuf::internal::ArenaStringPtr mqtt_broker_addr_;
    ::int32_t vmq_instance_id_;
    ::int32_t hops_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_proto_2fnodeinstance_2fcreate_2fv1_2fcreation_2eproto;
};

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// CreateNodeInstance

// string claim_id = 1;
inline void CreateNodeInstance::clear_claim_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.claim_id_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& CreateNodeInstance::claim_id() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:nodeinstance.create.v1.CreateNodeInstance.claim_id)
  return _internal_claim_id();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void CreateNodeInstance::set_claim_id(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.claim_id_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:nodeinstance.create.v1.CreateNodeInstance.claim_id)
}
inline ::std::string* PROTOBUF_NONNULL CreateNodeInstance::mutable_claim_id()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_claim_id();
  // @@protoc_insertion_point(field_mutable:nodeinstance.create.v1.CreateNodeInstance.claim_id)
  return _s;
}
inline const ::std::string& CreateNodeInstance::_internal_claim_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.claim_id_.Get();
}
inline void CreateNodeInstance::_internal_set_claim_id(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.claim_id_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL CreateNodeInstance::_internal_mutable_claim_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.claim_id_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE CreateNodeInstance::release_claim_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:nodeinstance.create.v1.CreateNodeInstance.claim_id)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.claim_id_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.claim_id_.Set("", GetArena());
  }
  return released;
}
inline void CreateNodeInstance::set_allocated_claim_id(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.claim_id_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.claim_id_.IsDefault()) {
    _impl_.claim_id_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:nodeinstance.create.v1.CreateNodeInstance.claim_id)
}

// string machine_guid = 2;
inline void CreateNodeInstance::clear_machine_guid() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.machine_guid_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& CreateNodeInstance::machine_guid() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:nodeinstance.create.v1.CreateNodeInstance.machine_guid)
  return _internal_machine_guid();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void CreateNodeInstance::set_machine_guid(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.machine_guid_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:nodeinstance.create.v1.CreateNodeInstance.machine_guid)
}
inline ::std::string* PROTOBUF_NONNULL CreateNodeInstance::mutable_machine_guid()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_machine_guid();
  // @@protoc_insertion_point(field_mutable:nodeinstance.create.v1.CreateNodeInstance.machine_guid)
  return _s;
}
inline const ::std::string& CreateNodeInstance::_internal_machine_guid() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.machine_guid_.Get();
}
inline void CreateNodeInstance::_internal_set_machine_guid(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.machine_guid_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL CreateNodeInstance::_internal_mutable_machine_guid() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.machine_guid_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE CreateNodeInstance::release_machine_guid() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:nodeinstance.create.v1.CreateNodeInstance.machine_guid)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.machine_guid_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.machine_guid_.Set("", GetArena());
  }
  return released;
}
inline void CreateNodeInstance::set_allocated_machine_guid(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.machine_guid_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.machine_guid_.IsDefault()) {
    _impl_.machine_guid_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:nodeinstance.create.v1.CreateNodeInstance.machine_guid)
}

// string hostname = 3;
inline void CreateNodeInstance::clear_hostname() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.hostname_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline const ::std::string& CreateNodeInstance::hostname() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:nodeinstance.create.v1.CreateNodeInstance.hostname)
  return _internal_hostname();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void CreateNodeInstance::set_hostname(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  _impl_.hostname_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:nodeinstance.create.v1.CreateNodeInstance.hostname)
}
inline ::std::string* PROTOBUF_NONNULL CreateNodeInstance::mutable_hostname()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::std::string* _s = _internal_mutable_hostname();
  // @@protoc_insertion_point(field_mutable:nodeinstance.create.v1.CreateNodeInstance.hostname)
  return _s;
}
inline const ::std::string& CreateNodeInstance::_internal_hostname() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.hostname_.Get();
}
inline void CreateNodeInstance::_internal_set_hostname(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.hostname_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL CreateNodeInstance::_internal_mutable_hostname() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.hostname_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE CreateNodeInstance::release_hostname() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:nodeinstance.create.v1.CreateNodeInstance.hostname)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000004U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  auto* released = _impl_.hostname_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.hostname_.Set("", GetArena());
  }
  return released;
}
inline void CreateNodeInstance::set_allocated_hostname(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }
  _impl_.hostname_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.hostname_.IsDefault()) {
    _impl_.hostname_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:nodeinstance.create.v1.CreateNodeInstance.hostname)
}

// int32 vmq_instance_id = 4;
inline void CreateNodeInstance::clear_vmq_instance_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.vmq_instance_id_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
inline ::int32_t CreateNodeInstance::vmq_instance_id() const {
  // @@protoc_insertion_point(field_get:nodeinstance.create.v1.CreateNodeInstance.vmq_instance_id)
  return _internal_vmq_instance_id();
}
inline void CreateNodeInstance::set_vmq_instance_id(::int32_t value) {
  _internal_set_vmq_instance_id(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  // @@protoc_insertion_point(field_set:nodeinstance.create.v1.CreateNodeInstance.vmq_instance_id)
}
inline ::int32_t CreateNodeInstance::_internal_vmq_instance_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.vmq_instance_id_;
}
inline void CreateNodeInstance::_internal_set_vmq_instance_id(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.vmq_instance_id_ = value;
}

// string mqtt_broker_addr = 5;
inline void CreateNodeInstance::clear_mqtt_broker_addr() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.mqtt_broker_addr_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
}
inline const ::std::string& CreateNodeInstance::mqtt_broker_addr() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:nodeinstance.create.v1.CreateNodeInstance.mqtt_broker_addr)
  return _internal_mqtt_broker_addr();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void CreateNodeInstance::set_mqtt_broker_addr(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  _impl_.mqtt_broker_addr_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:nodeinstance.create.v1.CreateNodeInstance.mqtt_broker_addr)
}
inline ::std::string* PROTOBUF_NONNULL CreateNodeInstance::mutable_mqtt_broker_addr()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::std::string* _s = _internal_mutable_mqtt_broker_addr();
  // @@protoc_insertion_point(field_mutable:nodeinstance.create.v1.CreateNodeInstance.mqtt_broker_addr)
  return _s;
}
inline const ::std::string& CreateNodeInstance::_internal_mqtt_broker_addr() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.mqtt_broker_addr_.Get();
}
inline void CreateNodeInstance::_internal_set_mqtt_broker_addr(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.mqtt_broker_addr_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL CreateNodeInstance::_internal_mutable_mqtt_broker_addr() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.mqtt_broker_addr_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE CreateNodeInstance::release_mqtt_broker_addr() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:nodeinstance.create.v1.CreateNodeInstance.mqtt_broker_addr)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000008U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  auto* released = _impl_.mqtt_broker_addr_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.mqtt_broker_addr_.Set("", GetArena());
  }
  return released;
}
inline void CreateNodeInstance::set_allocated_mqtt_broker_addr(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  }
  _impl_.mqtt_broker_addr_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.mqtt_broker_addr_.IsDefault()) {
    _impl_.mqtt_broker_addr_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:nodeinstance.create.v1.CreateNodeInstance.mqtt_broker_addr)
}

// int32 hops = 6;
inline void CreateNodeInstance::clear_hops() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.hops_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
}
inline ::int32_t CreateNodeInstance::hops() const {
  // @@protoc_insertion_point(field_get:nodeinstance.create.v1.CreateNodeInstance.hops)
  return _internal_hops();
}
inline void CreateNodeInstance::set_hops(::int32_t value) {
  _internal_set_hops(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  // @@protoc_insertion_point(field_set:nodeinstance.create.v1.CreateNodeInstance.hops)
}
inline ::int32_t CreateNodeInstance::_internal_hops() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.hops_;
}
inline void CreateNodeInstance::_internal_set_hops(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.hops_ = value;
}

// -------------------------------------------------------------------

// CreateNodeInstanceResult

// string node_id = 1;
inline void CreateNodeInstanceResult::clear_node_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.node_id_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& CreateNodeInstanceResult::node_id() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:nodeinstance.create.v1.CreateNodeInstanceResult.node_id)
  return _internal_node_id();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void CreateNodeInstanceResult::set_node_id(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.node_id_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:nodeinstance.create.v1.CreateNodeInstanceResult.node_id)
}
inline ::std::string* PROTOBUF_NONNULL CreateNodeInstanceResult::mutable_node_id()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_node_id();
  // @@protoc_insertion_point(field_mutable:nodeinstance.create.v1.CreateNodeInstanceResult.node_id)
  return _s;
}
inline const ::std::string& CreateNodeInstanceResult::_internal_node_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.node_id_.Get();
}
inline void CreateNodeInstanceResult::_internal_set_node_id(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.node_id_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL CreateNodeInstanceResult::_internal_mutable_node_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.node_id_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE CreateNodeInstanceResult::release_node_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:nodeinstance.create.v1.CreateNodeInstanceResult.node_id)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.node_id_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.node_id_.Set("", GetArena());
  }
  return released;
}
inline void CreateNodeInstanceResult::set_allocated_node_id(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.node_id_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.node_id_.IsDefault()) {
    _impl_.node_id_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:nodeinstance.create.v1.CreateNodeInstanceResult.node_id)
}

// string machine_guid = 2;
inline void CreateNodeInstanceResult::clear_machine_guid() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.machine_guid_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& CreateNodeInstanceResult::machine_guid() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:nodeinstance.create.v1.CreateNodeInstanceResult.machine_guid)
  return _internal_machine_guid();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void CreateNodeInstanceResult::set_machine_guid(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.machine_guid_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:nodeinstance.create.v1.CreateNodeInstanceResult.machine_guid)
}
inline ::std::string* PROTOBUF_NONNULL CreateNodeInstanceResult::mutable_machine_guid()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_machine_guid();
  // @@protoc_insertion_point(field_mutable:nodeinstance.create.v1.CreateNodeInstanceResult.machine_guid)
  return _s;
}
inline const ::std::string& CreateNodeInstanceResult::_internal_machine_guid() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.machine_guid_.Get();
}
inline void CreateNodeInstanceResult::_internal_set_machine_guid(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.machine_guid_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL CreateNodeInstanceResult::_internal_mutable_machine_guid() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.machine_guid_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE CreateNodeInstanceResult::release_machine_guid() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:nodeinstance.create.v1.CreateNodeInstanceResult.machine_guid)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.machine_guid_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.machine_guid_.Set("", GetArena());
  }
  return released;
}
inline void CreateNodeInstanceResult::set_allocated_machine_guid(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.machine_guid_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.machine_guid_.IsDefault()) {
    _impl_.machine_guid_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:nodeinstance.create.v1.CreateNodeInstanceResult.machine_guid)
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace v1
}  // namespace create
}  // namespace nodeinstance


// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"
// clang-format on

#endif  // proto_2fnodeinstance_2fcreate_2fv1_2fcreation_2eproto_2epb_2eh
